from datetime import datetime
from typing import List, Union

from pydantic import UUID4, BaseModel


class Image(BaseModel):
    uuid: UUID4

    class Config:
        orm_mode = True


class Item(BaseModel):
    uuid: UUID4
    received_at: datetime
    images: List[Image]
    deployed_at: Union[datetime, None] = None
    storage_name: str
    delivery_uuid: UUID4

    class Config:
        orm_mode = True


class Storage(BaseModel):
    name: str
    items: List[Item]

    class Config:
        orm_mode = True


class DeliveryBase(BaseModel):
    verification: Union[str, None] = None


class DeliveryUpdate(BaseModel):
    addressee: Union[str, None] = None
    team: Union[str, None] = None


class Delivery(DeliveryBase, DeliveryUpdate):
    uuid: UUID4
    tag: Union[str, None] = None
    items: List[Item]

    class Config:
        orm_mode = True


class LoginData(BaseModel):
    item_uuid: str
    signature: str
